.. Copyright 2013, 2016, 2018 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Package reahl.web.bootstrap.pagination
--------------------------------------

.. sidebar:: Examples in this section

   - tutorial.pagerbootstrap

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>


.. automodule:: reahl.web.bootstrap.pagination

.. uml:: ../../../../reahl-web/reahl/web_dev/bootstrap/pagination2.puml
.. uml:: ../../../../reahl-web/reahl/web_dev/bootstrap/pagination.puml

PageMenu
""""""""

.. autoclass:: PageMenu
   :members:


PagedPanel
""""""""""

.. autoclass:: PagedPanel
   :members:

PageIndex
"""""""""

.. autoclass:: PageIndex
   :members:

SequentialPageIndex
"""""""""""""""""""

.. autoclass:: SequentialPageIndex
   :members:

AnnualPageIndex
"""""""""""""""

.. autoclass:: AnnualPageIndex
   :members:
